All of lore.kernel.org
 help / color / mirror / Atom feed
* [PATCH] policy_tool.c
@ 2005-06-21  9:22 aq
  0 siblings, 0 replies; only message in thread
From: aq @ 2005-06-21  9:22 UTC (permalink / raw)
  To: xen-devel, xense-devel, Reiner Sailer

[-- Attachment #1: Type: text/plain, Size: 351 bytes --]

This patch is for policy_tool.c (ChangeSet@1.1727)
- fix few typos.
- handle the possible errors correctly.
- remove the (useless) ouput line "Policy dump End"

Signed-off-by: Nguyen Anh Quynh <aquynh@gmail.com>

# diffstat policy_tool2.patch 
 policy_tool.c |   23 +++++++++--------------
 1 files changed, 9 insertions(+), 14 deletions(-)

[-- Warning: decoded text below may be mangled, UTF-8 assumed --]
[-- Attachment #2: policy_tool2.patch --]
[-- Type: text/x-patch; name="policy_tool2.patch", Size: 1951 bytes --]

===== tools/policy/policy_tool.c 1.1 vs edited =====
--- 1.1/tools/policy/policy_tool.c	2005-06-21 07:28:06 +09:00
+++ edited/tools/policy/policy_tool.c	2005-06-21 18:13:46 +09:00
@@ -14,7 +14,7 @@
  *
  * sHype policy management tool. This code runs in a domain and
  *     manages the Xen security policy by interacting with the
  *     Xen access control module via a /proc/xen/policycmd proc-ioctl, 
  *     which is translated into a policy_op hypercall into Xen.
  * 
  * todo: implement setpolicy to dynamically set a policy cache.
@@ -229,7 +229,6 @@
 	default:
 		printf("UNKNOWN POLICY!\n");
 	}
-	printf("\nPolicy dump End.\n\n");
 }
 
 /*************************** set policy ****************************/
@@ -519,39 +518,35 @@
 int
 main(int argc, char **argv) {
 
-	int policycmd_fd;
+	int policycmd_fd, ret;
 
-	if (argc < 2)
+	if (argc < 2) 
 		usage(argv[0]);
 		
 	if ((policycmd_fd = open("/proc/xen/privcmd", O_RDONLY)) <= 0) {
-		    printf("ERROR: Could not open xen policycmd device!\n");
+		    printf("ERROR: Could not open xen privcmd device!\n");
 		    exit(-1);
 	}
 	    
 	if (!strcmp(argv[1], "setpolicy")) {
 		if (argc != 2)
 			usage(argv[0]);
-		acm_domain_setpolicy(policycmd_fd);
-
+		ret = acm_domain_setpolicy(policycmd_fd);
 	} else if (!strcmp(argv[1], "getpolicy")) {
 		if (argc != 2)
 			usage(argv[0]);
-		acm_domain_getpolicy(policycmd_fd);
-
+		ret = acm_domain_getpolicy(policycmd_fd);
 	} else if (!strcmp(argv[1], "loadpolicy")) {
 		if (argc != 3) 
 			usage(argv[0]);
-		acm_domain_loadpolicy(policycmd_fd, argv[2]);
-
+		ret = acm_domain_loadpolicy(policycmd_fd, argv[2]);
 	} else if (!strcmp(argv[1], "dumpstats")) {
 		if (argc != 2) 
 			usage(argv[0]);
-		acm_domain_dumpstats(policycmd_fd);
-
+		ret = acm_domain_dumpstats(policycmd_fd);
 	} else
 		usage(argv[0]);
 
 	close(policycmd_fd);
-	return 0;
+	return ret;
 }

[-- Attachment #3: Type: text/plain, Size: 138 bytes --]

_______________________________________________
Xen-devel mailing list
Xen-devel@lists.xensource.com
http://lists.xensource.com/xen-devel

^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2005-06-21  9:22 UTC | newest]

Thread overview: (only message) (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
@@ -14,7 +14,7 @@
  * sHype policy management tool. This code runs in a domain and
  *     manages the Xen security policy by interacting with the
- *     Xen access control module via a /proc/xen/policycmd proc-ioctl, 
+ *     Xen access control module via a /proc/xen/privcmd proc-ioctl, 
  *     which is translated into a policy_op hypercall into Xen.
  * 
2005-06-21  9:22 [PATCH] policy_tool.c aq

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.